@@ -2,12 +2,11 @@
 # @author: zhangping
 
 import json
-import logging
 import datetime as dt
 import numpy as np
 import pandas as pd
 from urllib import parse
-from .utils import HttpUtil
+from .utils import HttpUtil, LoggerUtil
 
 
 class ApiClient():
@@ -15,13 +14,13 @@ class ApiClient():
     指标数据接口客户类
     '''
 
-    def __init__(self, token='', host='api.shducheng.net', port=80, log_level=logging.INFO, api_urls=None):
+    def __init__(self, token='', host='api.shducheng.net', port=80, log_level='INFO', logs_dir='./logs', api_urls=None):
         '''
         ApiClient构造函数
         :param token: token字符串
         :param host: 接口服务地址，默认：api.shducheng.net
         :param port: 接口服务端口，默认：80
-        :param log_level: 日志级别，默认：logging.INFO
+        :param log_level: 日志级别，默认：INFO
         :param api_urls: 接口地址服务路径
         :return:
         '''
@@ -43,16 +42,7 @@ class ApiClient():
         self.api_dict_list = self.host + api_urls['api_dict_list']
         self.api_msg_sms = self.host + api_urls['api_msg_sms']
         self.api_msg_wx = self.host + api_urls['api_msg_wx']
-        self.init_logger(log_level)
-
-    def init_logger(self, log_level=logging.INFO):
-        log_fmt = '%(asctime)s - %(filename)s[line:%(lineno)d]- %(levelname)s: %(message)s'
-        log_handler = logging.StreamHandler()
-        log_handler.setLevel(log_level)
-        log_handler.setFormatter(logging.Formatter(fmt=log_fmt))
-        self.logger = logging.getLogger()
-        self.logger.setLevel(log_level)
-        self.logger.addHandler(log_handler)
+        self.logger = LoggerUtil.get_logger(name='dqapi', level=log_level, logs_dir=logs_dir)
 
     def get_idx_dict(self, idx):
         '''
